@@ -1,13 +1,26 @@
 import argparse
 import contextlib
+import itertools
 import logging
 from pathlib import Path
 import shutil
 import sys
 import textwrap
-from typing import Any, Generator, Iterable, List, Mapping, Optional, Sequence, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Union,
+)
 
 import mdformat
+from mdformat._compat import importlib_metadata
 from mdformat._util import atomic_write, is_md_equal
 import mdformat.plugins
 import mdformat.renderer
@@ -31,7 +44,7 @@ def run(cli_args: Sequence[str]) -> int:  # noqa: C901
         for plugin in enabled_parserplugins.values()
     )
 
-    arg_parser = make_arg_parser(enabled_parserplugins.values())
+    arg_parser = make_arg_parser(enabled_parserplugins, enabled_codeformatters)
     args = arg_parser.parse_args(cli_args)
     if not args.paths:
         print_paragraphs(["No files have been passed in. Doing nothing."])
@@ -55,13 +68,15 @@ def run(cli_args: Sequence[str]) -> int:  # noqa: C901
             path_str = "-"
             original_str = sys.stdin.read()
 
-        with log_handler_applied(mdformat.renderer.LOGGER, renderer_warning_printer):
-            formatted_str = mdformat.text(
-                original_str,
-                options=options,
-                extensions=enabled_parserplugins,
-                codeformatters=enabled_codeformatters,
-            )
+        formatted_str = mdformat.text(
+            original_str,
+            options=options,
+            extensions=enabled_parserplugins,
+            codeformatters=enabled_codeformatters,
+            _first_pass_contextmanager=log_handler_applied(
+                mdformat.renderer.LOGGER, renderer_warning_printer
+            ),
+        )
 
         if args.check:
             if formatted_str != original_str:
@@ -104,18 +119,24 @@ def validate_wrap_arg(value: str) -> Union[str, int]:
 
 
 def make_arg_parser(
-    parser_plugins: Iterable[mdformat.plugins.ParserExtensionInterface],
+    parser_extensions: Mapping[str, mdformat.plugins.ParserExtensionInterface],
+    codeformatters: Mapping[str, Callable[[str, str], str]],
 ) -> argparse.ArgumentParser:
+    plugin_versions_str = get_plugin_versions_str(parser_extensions, codeformatters)
     parser = argparse.ArgumentParser(
-        description="CommonMark compliant Markdown formatter"
+        description="CommonMark compliant Markdown formatter",
+        epilog=f"Installed plugins: {plugin_versions_str}"
+        if plugin_versions_str
+        else None,
     )
     parser.add_argument("paths", nargs="*", help="files to format")
     parser.add_argument(
         "--check", action="store_true", help="do not apply changes to files"
     )
-    parser.add_argument(
-        "--version", action="version", version=f"mdformat {mdformat.__version__}"
-    )
+    version_str = f"mdformat {mdformat.__version__}"
+    if plugin_versions_str:
+        version_str += f" ({plugin_versions_str})"
+    parser.add_argument("--version", action="version", version=version_str)
     parser.add_argument(
         f"--{CONSECUTIVE_KEY}",
         action="store_true",
@@ -128,7 +149,7 @@ def make_arg_parser(
         metavar="{keep,no,INTEGER}",
         help="paragraph word wrap mode (default: keep)",
     )
-    for plugin in parser_plugins:
+    for plugin in parser_extensions.values():
         if hasattr(plugin, "add_cli_options"):
             plugin.add_cli_options(parser)
     return parser
@@ -208,3 +229,32 @@ def log_handler_applied(
         yield
     finally:
         logger.removeHandler(handler)
+
+
+def get_plugin_versions(
+    parser_extensions: Mapping[str, mdformat.plugins.ParserExtensionInterface],
+    codeformatters: Mapping[str, Callable[[str, str], str]],
+) -> Dict[str, str]:
+    versions = {}
+    for iface in itertools.chain(parser_extensions.values(), codeformatters.values()):
+        # Packages and modules should have `__package__`
+        if hasattr(iface, "__package__"):
+            package_name = iface.__package__  # type: ignore
+        else:  # class or function
+            module_name = iface.__module__
+            package_name = module_name.split(".", maxsplit=1)[0]
+        try:
+            package_version = importlib_metadata.version(package_name)
+        except importlib_metadata.PackageNotFoundError:
+            # In test scenarios the package may not exist
+            package_version = "unknown"
+        versions[package_name] = package_version
+    return versions
+
+
+def get_plugin_versions_str(
+    parser_extensions: Mapping[str, mdformat.plugins.ParserExtensionInterface],
+    codeformatters: Mapping[str, Callable[[str, str], str]],
+) -> str:
+    plugin_versions = get_plugin_versions(parser_extensions, codeformatters)
+    return ", ".join(f"{name}: {version}" for name, version in plugin_versions.items())
